# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.user_memory_fact_get import UserMemoryFactGet  # noqa: E501

class TestUserMemoryFactGet(unittest.TestCase):
    """UserMemoryFactGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserMemoryFactGet:
        """Test UserMemoryFactGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserMemoryFactGet`
        """
        model = UserMemoryFactGet()  # noqa: E501
        if include_optional:
            return UserMemoryFactGet(
                access_count = 56,
                content = '',
                created_at = 56,
                fact_type = 'preference',
                id = 56,
                importance = 56,
                last_accessed_at = 56,
                source_chat_id = 56,
                valid_from = 56
            )
        else:
            return UserMemoryFactGet(
                access_count = 56,
                content = '',
                created_at = 56,
                fact_type = 'preference',
                id = 56,
                importance = 56,
                last_accessed_at = 56,
                valid_from = 56,
        )
        """

    def testUserMemoryFactGet(self):
        """Test UserMemoryFactGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ai_assistant_server_connector.models.ai_assistant_reponse_stream_request import AIAssistantReponseStreamRequest
from ai_assistant_server_connector.models.ai_assistant_session_start import AIAssistantSessionStart
from ai_assistant_server_connector.models.ai_assistant_custom_skill_create import AiAssistantCustomSkillCreate
from ai_assistant_server_connector.models.ai_assistant_custom_skill_get import AiAssistantCustomSkillGet
from ai_assistant_server_connector.models.ai_assistant_custom_skill_patch import AiAssistantCustomSkillPatch
from ai_assistant_server_connector.models.ai_assistant_custom_skill_update import AiAssistantCustomSkillUpdate
from ai_assistant_server_connector.models.ai_assistant_get import AiAssistantGet
from ai_assistant_server_connector.models.ai_assistant_goal_create import AiAssistantGoalCreate
from ai_assistant_server_connector.models.ai_assistant_goal_create_update import AiAssistantGoalCreateUpdate
from ai_assistant_server_connector.models.ai_assistant_goal_get import AiAssistantGoalGet
from ai_assistant_server_connector.models.ai_assistant_lexicon_item import AiAssistantLexiconItem
from ai_assistant_server_connector.models.ai_assistant_lexicon_item_create_or_update import AiAssistantLexiconItemCreateOrUpdate
from ai_assistant_server_connector.models.ai_assistant_lexicon_item_new import AiAssistantLexiconItemNew
from ai_assistant_server_connector.models.ai_assistant_list_get import AiAssistantListGet
from ai_assistant_server_connector.models.ai_assistant_new import AiAssistantNew
from ai_assistant_server_connector.models.ai_assistant_setting_toggle import AiAssistantSettingToggle
from ai_assistant_server_connector.models.ai_assistant_setup_from_root import AiAssistantSetupFromRoot
from ai_assistant_server_connector.models.ai_assistant_skill_setting_get import AiAssistantSkillSettingGet
from ai_assistant_server_connector.models.ai_assistant_tool_setting_get import AiAssistantToolSettingGet
from ai_assistant_server_connector.models.ai_assistant_update import AiAssistantUpdate
from ai_assistant_server_connector.models.ai_assistant_usage_log_read import AiAssistantUsageLogRead
from ai_assistant_server_connector.models.ai_assistant_usage_logs_by_sessions_request import AiAssistantUsageLogsBySessionsRequest
from ai_assistant_server_connector.models.assistant_function import AssistantFunction
from ai_assistant_server_connector.models.assistant_type import AssistantType
from ai_assistant_server_connector.models.assistant_usage_type import AssistantUsageType
from ai_assistant_server_connector.models.avatar_option_get import AvatarOptionGet
from ai_assistant_server_connector.models.chat_history_chat_content import ChatHistoryChatContent
from ai_assistant_server_connector.models.chat_history_item import ChatHistoryItem
from ai_assistant_server_connector.models.chat_message_attachment import ChatMessageAttachment
from ai_assistant_server_connector.models.chat_message_attachment_type import ChatMessageAttachmentType
from ai_assistant_server_connector.models.chat_role import ChatRole
from ai_assistant_server_connector.models.collection_state import CollectionState
from ai_assistant_server_connector.models.collection_status import CollectionStatus
from ai_assistant_server_connector.models.conversation_style import ConversationStyle
from ai_assistant_server_connector.models.course_module_public import CourseModulePublic
from ai_assistant_server_connector.models.course_payment_type_str_enum import CoursePaymentTypeStrEnum
from ai_assistant_server_connector.models.course_public import CoursePublic
from ai_assistant_server_connector.models.emphemeral_credentials import EmphemeralCredentials
from ai_assistant_server_connector.models.fact_type import FactType
from ai_assistant_server_connector.models.goal_engagement_preset_get import GoalEngagementPresetGet
from ai_assistant_server_connector.models.goal_interactions_summary import GoalInteractionsSummary
from ai_assistant_server_connector.models.http_validation_error import HTTPValidationError
from ai_assistant_server_connector.models.interaction_type import InteractionType
from ai_assistant_server_connector.models.knowledgebase_state import KnowledgebaseState
from ai_assistant_server_connector.models.language_str_enum import LanguageStrEnum
from ai_assistant_server_connector.models.location_inner import LocationInner
from ai_assistant_server_connector.models.memory_fact_forget_request import MemoryFactForgetRequest
from ai_assistant_server_connector.models.memory_fact_record_request import MemoryFactRecordRequest
from ai_assistant_server_connector.models.memory_ingest_request import MemoryIngestRequest
from ai_assistant_server_connector.models.module_lesson_public import ModuleLessonPublic
from ai_assistant_server_connector.models.portal_ai_info_get import PortalAiInfoGet
from ai_assistant_server_connector.models.portal_ai_info_update import PortalAiInfoUpdate
from ai_assistant_server_connector.models.portal_info_request import PortalInfoRequest
from ai_assistant_server_connector.models.portal_owner_info import PortalOwnerInfo
from ai_assistant_server_connector.models.rag_query_response import RagQueryResponse
from ai_assistant_server_connector.models.response_chunk import ResponseChunk
from ai_assistant_server_connector.models.response_chunk_type import ResponseChunkType
from ai_assistant_server_connector.models.response_wrapper import ResponseWrapper
from ai_assistant_server_connector.models.response_wrapper_ai_assistant_session_start import ResponseWrapperAIAssistantSessionStart
from ai_assistant_server_connector.models.response_wrapper_ai_assistant_get import ResponseWrapperAiAssistantGet
from ai_assistant_server_connector.models.response_wrapper_bool import ResponseWrapperBool
from ai_assistant_server_connector.models.response_wrapper_int import ResponseWrapperInt
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_custom_skill_get import ResponseWrapperListAiAssistantCustomSkillGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_goal_get import ResponseWrapperListAiAssistantGoalGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_list_get import ResponseWrapperListAiAssistantListGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_skill_setting_get import ResponseWrapperListAiAssistantSkillSettingGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_tool_setting_get import ResponseWrapperListAiAssistantToolSettingGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_usage_log_read import ResponseWrapperListAiAssistantUsageLogRead
from ai_assistant_server_connector.models.response_wrapper_list_avatar_option_get import ResponseWrapperListAvatarOptionGet
from ai_assistant_server_connector.models.response_wrapper_list_goal_engagement_preset_get import ResponseWrapperListGoalEngagementPresetGet
from ai_assistant_server_connector.models.response_wrapper_list_user_memory_fact_get import ResponseWrapperListUserMemoryFactGet
from ai_assistant_server_connector.models.response_wrapper_list_voice_option_get import ResponseWrapperListVoiceOptionGet
from ai_assistant_server_connector.models.response_wrapper_portal_ai_info_get import ResponseWrapperPortalAiInfoGet
from ai_assistant_server_connector.models.response_wrapper_rag_query_response import ResponseWrapperRagQueryResponse
from ai_assistant_server_connector.models.response_wrapper_user_memory_profile_get import ResponseWrapperUserMemoryProfileGet
from ai_assistant_server_connector.models.result import Result
from ai_assistant_server_connector.models.score import Score
from ai_assistant_server_connector.models.search_result import SearchResult
from ai_assistant_server_connector.models.usage_details import UsageDetails
from ai_assistant_server_connector.models.user_goal_interaction_create import UserGoalInteractionCreate
from ai_assistant_server_connector.models.user_memory_fact_get import UserMemoryFactGet
from ai_assistant_server_connector.models.user_memory_profile_get import UserMemoryProfileGet
from ai_assistant_server_connector.models.validation_error import ValidationError
from ai_assistant_server_connector.models.voice_option_get import VoiceOptionGet



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr

class MemoryIngestRequest(BaseModel):
    """
    Payload posted by agent_repo at run finalization.  # noqa: E501
    """
    assistant_message: StrictStr = Field(...)
    chat_id: StrictInt = Field(...)
    portal_member_id: StrictInt = Field(...)
    run_id: StrictStr = Field(...)
    user_message: StrictStr = Field(...)
    __properties = ["assistant_message", "chat_id", "portal_member_id", "run_id", "user_message"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MemoryIngestRequest:
        """Create an instance of MemoryIngestRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MemoryIngestRequest:
        """Create an instance of MemoryIngestRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MemoryIngestRequest.parse_obj(obj)

        _obj = MemoryIngestRequest.parse_obj({
            "assistant_message": obj.get("assistant_message"),
            "chat_id": obj.get("chat_id"),
            "portal_member_id": obj.get("portal_member_id"),
            "run_id": obj.get("run_id"),
            "user_message": obj.get("user_message")
        })
        return _obj





# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from ai_assistant_server_connector.models.fact_type import FactType

class UserMemoryFactGet(BaseModel):
    """
    Read DTO for a single fact returned to the end user.  Omits ``embedding`` (large, internal) and ``portal_member_id`` (implicit from auth). ``valid_to`` is always None for rows we expose, so dropped.  # noqa: E501
    """
    access_count: StrictInt = Field(...)
    content: StrictStr = Field(...)
    created_at: StrictInt = Field(...)
    fact_type: FactType = Field(...)
    id: StrictInt = Field(...)
    importance: StrictInt = Field(...)
    last_accessed_at: StrictInt = Field(...)
    source_chat_id: Optional[StrictInt] = None
    valid_from: StrictInt = Field(...)
    __properties = ["access_count", "content", "created_at", "fact_type", "id", "importance", "last_accessed_at", "source_chat_id", "valid_from"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UserMemoryFactGet:
        """Create an instance of UserMemoryFactGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UserMemoryFactGet:
        """Create an instance of UserMemoryFactGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UserMemoryFactGet.parse_obj(obj)

        _obj = UserMemoryFactGet.parse_obj({
            "access_count": obj.get("access_count"),
            "content": obj.get("content"),
            "created_at": obj.get("created_at"),
            "fact_type": obj.get("fact_type"),
            "id": obj.get("id"),
            "importance": obj.get("importance"),
            "last_accessed_at": obj.get("last_accessed_at"),
            "source_chat_id": obj.get("source_chat_id"),
            "valid_from": obj.get("valid_from")
        })
        return _obj





# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_usage_log_read import AiAssistantUsageLogRead  # noqa: E501

class TestAiAssistantUsageLogRead(unittest.TestCase):
    """AiAssistantUsageLogRead unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantUsageLogRead:
        """Test AiAssistantUsageLogRead
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantUsageLogRead`
        """
        model = AiAssistantUsageLogRead()  # noqa: E501
        if include_optional:
            return AiAssistantUsageLogRead(
                ai_assistant_id = 56,
                commited_at = 56,
                created_at = 56,
                id = 56,
                incoming_tokens = 56,
                model = '',
                outgoing_tokens = 56,
                portal_member_id = 56,
                price_incoming = 1.337,
                price_outgoing = 1.337,
                price_usd = 1.337,
                session_id = '',
                usage_type = 'text'
            )
        else:
            return AiAssistantUsageLogRead(
                ai_assistant_id = 56,
                created_at = 56,
                id = 56,
                model = '',
                portal_member_id = 56,
                session_id = '',
                usage_type = 'text',
        )
        """

    def testAiAssistantUsageLogRead(self):
        """Test AiAssistantUsageLogRead"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from ai_assistant_server_connector.models.chat_history_item import ChatHistoryItem
from ai_assistant_server_connector.models.chat_message_attachment import ChatMessageAttachment
from ai_assistant_server_connector.models.portal_info_request import PortalInfoRequest

class AIAssistantReponseStreamRequest(BaseModel):
    """
    AIAssistantReponseStreamRequest
    """
    assistant_chat_member_id: StrictInt = Field(...)
    attachments: Optional[conlist(ChatMessageAttachment)] = None
    chat_id: StrictInt = Field(...)
    chat_session_id: StrictInt = Field(...)
    history: conlist(ChatHistoryItem) = Field(...)
    name_chat: Optional[StrictBool] = False
    portal_info: Optional[PortalInfoRequest] = None
    session_id: StrictStr = Field(...)
    user_prompt: StrictStr = Field(...)
    __properties = ["assistant_chat_member_id", "attachments", "chat_id", "chat_session_id", "history", "name_chat", "portal_info", "session_id", "user_prompt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AIAssistantReponseStreamRequest:
        """Create an instance of AIAssistantReponseStreamRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item in self.attachments:
                if _item:
                    _items.append(_item.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in history (list)
        _items = []
        if self.history:
            for _item in self.history:
                if _item:
                    _items.append(_item.to_dict())
            _dict['history'] = _items
        # override the default output from pydantic by calling `to_dict()` of portal_info
        if self.portal_info:
            _dict['portal_info'] = self.portal_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AIAssistantReponseStreamRequest:
        """Create an instance of AIAssistantReponseStreamRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AIAssistantReponseStreamRequest.parse_obj(obj)

        _obj = AIAssistantReponseStreamRequest.parse_obj({
            "assistant_chat_member_id": obj.get("assistant_chat_member_id"),
            "attachments": [ChatMessageAttachment.from_dict(_item) for _item in obj.get("attachments")] if obj.get("attachments") is not None else None,
            "chat_id": obj.get("chat_id"),
            "chat_session_id": obj.get("chat_session_id"),
            "history": [ChatHistoryItem.from_dict(_item) for _item in obj.get("history")] if obj.get("history") is not None else None,
            "name_chat": obj.get("name_chat") if obj.get("name_chat") is not None else False,
            "portal_info": PortalInfoRequest.from_dict(obj.get("portal_info")) if obj.get("portal_info") is not None else None,
            "session_id": obj.get("session_id"),
            "user_prompt": obj.get("user_prompt")
        })
        return _obj





# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class PortalAiInfoGet(BaseModel):
    """
    PortalAiInfoGet
    """
    academy_info: Optional[StrictStr] = None
    agent_name: Optional[StrictStr] = None
    agent_personality: Optional[StrictStr] = None
    created_at: StrictInt = Field(...)
    goal: Optional[StrictStr] = None
    last_updated_at: StrictInt = Field(...)
    portal_id: StrictInt = Field(...)
    portal_owner_info: Optional[StrictStr] = None
    __properties = ["academy_info", "agent_name", "agent_personality", "created_at", "goal", "last_updated_at", "portal_id", "portal_owner_info"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PortalAiInfoGet:
        """Create an instance of PortalAiInfoGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PortalAiInfoGet:
        """Create an instance of PortalAiInfoGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PortalAiInfoGet.parse_obj(obj)

        _obj = PortalAiInfoGet.parse_obj({
            "academy_info": obj.get("academy_info"),
            "agent_name": obj.get("agent_name"),
            "agent_personality": obj.get("agent_personality"),
            "created_at": obj.get("created_at"),
            "goal": obj.get("goal"),
            "last_updated_at": obj.get("last_updated_at"),
            "portal_id": obj.get("portal_id"),
            "portal_owner_info": obj.get("portal_owner_info")
        })
        return _obj





# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector.api.memory_api import MemoryApi  # noqa: E501


class TestMemoryApi(unittest.IsolatedAsyncioTestCase):
    """MemoryApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = MemoryApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_ai_assistant_api_clear_all_facts(self) -> None:
        """Test case for ai_assistant_api_clear_all_facts

        Clear All Facts  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_clear_profile(self) -> None:
        """Test case for ai_assistant_api_clear_profile

        Clear Profile  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_count_facts(self) -> None:
        """Test case for ai_assistant_api_count_facts

        Count Facts  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_delete_fact(self) -> None:
        """Test case for ai_assistant_api_delete_fact

        Delete Fact  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_delete_profile_key(self) -> None:
        """Test case for ai_assistant_api_delete_profile_key

        Delete Profile Key  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_get_profile(self) -> None:
        """Test case for ai_assistant_api_get_profile

        Get Profile  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_list_facts(self) -> None:
        """Test case for ai_assistant_api_list_facts

        List Facts  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_memory_forget_facts(self) -> None:
        """Test case for ai_assistant_api_memory_forget_facts

        Memory Forget Facts  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_memory_ingest(self) -> None:
        """Test case for ai_assistant_api_memory_ingest

        Memory Ingest  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_memory_record_fact(self) -> None:
        """Test case for ai_assistant_api_memory_record_fact

        Memory Record Fact  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from ai_assistant_server_connector.models.assistant_usage_type import AssistantUsageType

class AiAssistantUsageLogRead(BaseModel):
    """
    AiAssistantUsageLogRead
    """
    ai_assistant_id: StrictInt = Field(...)
    commited_at: Optional[StrictInt] = None
    created_at: StrictInt = Field(...)
    id: StrictInt = Field(...)
    incoming_tokens: Optional[StrictInt] = None
    model: StrictStr = Field(...)
    outgoing_tokens: Optional[StrictInt] = None
    portal_member_id: StrictInt = Field(...)
    price_incoming: Optional[Union[StrictFloat, StrictInt]] = None
    price_outgoing: Optional[Union[StrictFloat, StrictInt]] = None
    price_usd: Optional[Union[StrictFloat, StrictInt]] = None
    session_id: StrictStr = Field(...)
    usage_type: AssistantUsageType = Field(...)
    __properties = ["ai_assistant_id", "commited_at", "created_at", "id", "incoming_tokens", "model", "outgoing_tokens", "portal_member_id", "price_incoming", "price_outgoing", "price_usd", "session_id", "usage_type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AiAssistantUsageLogRead:
        """Create an instance of AiAssistantUsageLogRead from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AiAssistantUsageLogRead:
        """Create an instance of AiAssistantUsageLogRead from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AiAssistantUsageLogRead.parse_obj(obj)

        _obj = AiAssistantUsageLogRead.parse_obj({
            "ai_assistant_id": obj.get("ai_assistant_id"),
            "commited_at": obj.get("commited_at"),
            "created_at": obj.get("created_at"),
            "id": obj.get("id"),
            "incoming_tokens": obj.get("incoming_tokens"),
            "model": obj.get("model"),
            "outgoing_tokens": obj.get("outgoing_tokens"),
            "portal_member_id": obj.get("portal_member_id"),
            "price_incoming": obj.get("price_incoming"),
            "price_outgoing": obj.get("price_outgoing"),
            "price_usd": obj.get("price_usd"),
            "session_id": obj.get("session_id"),
            "usage_type": obj.get("usage_type")
        })
        return _obj





# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictInt

class GoalInteractionsSummary(BaseModel):
    """
    GoalInteractionsSummary
    """
    is_available: Optional[StrictBool] = True
    last_engagement_at: Optional[StrictInt] = None
    last_opt_out_at: Optional[StrictInt] = None
    recent_interaction_count: Optional[StrictInt] = 0
    total_interaction_count: Optional[StrictInt] = 0
    __properties = ["is_available", "last_engagement_at", "last_opt_out_at", "recent_interaction_count", "total_interaction_count"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GoalInteractionsSummary:
        """Create an instance of GoalInteractionsSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GoalInteractionsSummary:
        """Create an instance of GoalInteractionsSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GoalInteractionsSummary.parse_obj(obj)

        _obj = GoalInteractionsSummary.parse_obj({
            "is_available": obj.get("is_available") if obj.get("is_available") is not None else True,
            "last_engagement_at": obj.get("last_engagement_at"),
            "last_opt_out_at": obj.get("last_opt_out_at"),
            "recent_interaction_count": obj.get("recent_interaction_count") if obj.get("recent_interaction_count") is not None else 0,
            "total_interaction_count": obj.get("total_interaction_count") if obj.get("total_interaction_count") is not None else 0
        })
        return _obj





# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_usage_log_read import ResponseWrapperListAiAssistantUsageLogRead  # noqa: E501

class TestResponseWrapperListAiAssistantUsageLogRead(unittest.TestCase):
    """ResponseWrapperListAiAssistantUsageLogRead unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListAiAssistantUsageLogRead:
        """Test ResponseWrapperListAiAssistantUsageLogRead
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListAiAssistantUsageLogRead`
        """
        model = ResponseWrapperListAiAssistantUsageLogRead()  # noqa: E501
        if include_optional:
            return ResponseWrapperListAiAssistantUsageLogRead(
                done = True,
                error = '',
                result = [
                    ai_assistant_server_connector.models.ai_assistant_usage_log_read.AiAssistantUsageLogRead(
                        ai_assistant_id = 56, 
                        commited_at = 56, 
                        created_at = 56, 
                        id = 56, 
                        incoming_tokens = 56, 
                        model = '', 
                        outgoing_tokens = 56, 
                        portal_member_id = 56, 
                        price_incoming = 1.337, 
                        price_outgoing = 1.337, 
                        price_usd = 1.337, 
                        session_id = '', 
                        usage_type = 'text', )
                    ]
            )
        else:
            return ResponseWrapperListAiAssistantUsageLogRead(
                done = True,
        )
        """

    def testResponseWrapperListAiAssistantUsageLogRead(self):
        """Test ResponseWrapperListAiAssistantUsageLogRead"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector.api.assistants_api import AssistantsApi  # noqa: E501


class TestAssistantsApi(unittest.IsolatedAsyncioTestCase):
    """AssistantsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = AssistantsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_ai_assistant_api_assistant_add(self) -> None:
        """Test case for ai_assistant_api_assistant_add

        Assistant Add  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_delete(self) -> None:
        """Test case for ai_assistant_api_assistant_delete

        Assistant Delete  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_get(self) -> None:
        """Test case for ai_assistant_api_assistant_get

        Assistant Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_landing_primary_get(self) -> None:
        """Test case for ai_assistant_api_assistant_landing_primary_get

        Assistant Landing Primary Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_landing_primary_update(self) -> None:
        """Test case for ai_assistant_api_assistant_landing_primary_update

        Assistant Landing Primary Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_primary_get(self) -> None:
        """Test case for ai_assistant_api_assistant_primary_get

        Assistant Primary Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_primary_goals_engagement_add(self) -> None:
        """Test case for ai_assistant_api_assistant_primary_goals_engagement_add

        Assistant Primary Goals Engagement Add  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_primary_goals_get(self) -> None:
        """Test case for ai_assistant_api_assistant_primary_goals_get

        Assistant Primary Goals Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_primary_update(self) -> None:
        """Test case for ai_assistant_api_assistant_primary_update

        Assistant Primary Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_response_stream(self) -> None:
        """Test case for ai_assistant_api_assistant_response_stream

        Assistant Response Stream  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_run_cancel(self) -> None:
        """Test case for ai_assistant_api_assistant_run_cancel

        Assistant Run Cancel  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_session_start(self) -> None:
        """Test case for ai_assistant_api_assistant_session_start

        Assistant Session Start  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_shared_primary_get(self) -> None:
        """Test case for ai_assistant_api_assistant_shared_primary_get

        Assistant Shared Primary Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_shared_primary_update(self) -> None:
        """Test case for ai_assistant_api_assistant_shared_primary_update

        Assistant Shared Primary Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_update(self) -> None:
        """Test case for ai_assistant_api_assistant_update

        Assistant Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assitants_list(self) -> None:
        """Test case for ai_assistant_api_assitants_list

        Assitants List  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skill_create(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skill_create

        Shared Primary Custom Skill Create  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skill_delete(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skill_delete

        Shared Primary Custom Skill Delete  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skill_patch(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skill_patch

        Shared Primary Custom Skill Patch  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skill_update(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skill_update

        Shared Primary Custom Skill Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skills_get(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skills_get

        Shared Primary Custom Skills Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_skill_settings_get(self) -> None:
        """Test case for ai_assistant_api_shared_primary_skill_settings_get

        Shared Primary Skill Settings Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_skill_toggle(self) -> None:
        """Test case for ai_assistant_api_shared_primary_skill_toggle

        Shared Primary Skill Toggle  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_tool_settings_get(self) -> None:
        """Test case for ai_assistant_api_shared_primary_tool_settings_get

        Shared Primary Tool Settings Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_tool_toggle(self) -> None:
        """Test case for ai_assistant_api_shared_primary_tool_toggle

        Shared Primary Tool Toggle  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conint, constr
from ai_assistant_server_connector.models.fact_type import FactType

class MemoryFactRecordRequest(BaseModel):
    """
    Payload for the ``remember`` tool — write one fact synchronously.  Triggered when the user explicitly tells the agent to remember something. Bypasses the post-hoc extractor (which runs async) so the agent's \"I'll remember that\" confirmation is grounded in an actual write.  # noqa: E501
    """
    chat_id: Optional[StrictInt] = None
    content: constr(strict=True, min_length=1) = Field(...)
    fact_type: Optional[FactType] = None
    importance: Optional[conint(strict=True, le=10, ge=1)] = 9
    portal_member_id: StrictInt = Field(...)
    run_id: Optional[StrictStr] = None
    __properties = ["chat_id", "content", "fact_type", "importance", "portal_member_id", "run_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MemoryFactRecordRequest:
        """Create an instance of MemoryFactRecordRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MemoryFactRecordRequest:
        """Create an instance of MemoryFactRecordRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MemoryFactRecordRequest.parse_obj(obj)

        _obj = MemoryFactRecordRequest.parse_obj({
            "chat_id": obj.get("chat_id"),
            "content": obj.get("content"),
            "fact_type": obj.get("fact_type"),
            "importance": obj.get("importance") if obj.get("importance") is not None else 9,
            "portal_member_id": obj.get("portal_member_id"),
            "run_id": obj.get("run_id")
        })
        return _obj


